@@ -34,4 +34,4 @@ class Delegated(AuthenticationBase):
             raise ValueError('Either id_token or refresh_token must '
                              'have a value')
 
-        return self.post('https://{}/delegation'.format(self.domain), data=data)
+        return self.post('{}://{}/delegation'.format(self.protocol, self.domain), data=data)
