@@ -2,7 +2,6 @@ from .rest import RestClient
 
 
 class Roles(object):
-
     """Auth0 roles endpoints
 
     Args:
@@ -19,12 +18,13 @@ class Roles(object):
             (defaults to 5.0 for both)
     """
 
-    def __init__(self, domain, token, telemetry=True, timeout=5.0):
+    def __init__(self, domain, token, telemetry=True, timeout=5.0, protocol="https"):
         self.domain = domain
+        self.protocol = protocol
         self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
 
     def _url(self, id=None):
-        url = 'https://{}/api/v2/roles'.format(self.domain)
+        url = '{}://{}/api/v2/roles'.format(self.protocol, self.domain)
         if id is not None:
             return '{}/{}'.format(url, id)
         return url
@@ -33,15 +33,17 @@ class Roles(object):
         """List or search roles.
 
         Args:
-            page (int, optional): The result's page number (zero based).
+            page (int, optional): The result's page number (zero based). By default,
+               retrieves the first page of results.
 
-            per_page (int, optional): The amount of entries per page.
+            per_page (int, optional): The amount of entries per page. By default,
+               retrieves 25 results per page.
 
             include_totals (bool, optional): True if the query summary is
-                to be included in the result, False otherwise.
+                to be included in the result, False otherwise. Defaults to True.
 
             name_filter (str, optional): A case-insensitive filter to apply
-                to search for roles by name            
+                to search for roles by name.
 
         See: https://auth0.com/docs/api/management/v2#!/Roles/get_roles
         """
@@ -57,7 +59,9 @@ class Roles(object):
         """Creates a new role.
 
         Args:
-            body (dict): Please see: https://auth0.com/docs/api/v2#!/Roles/post_roles
+            body (dict): the attributes for the role to create.
+
+        See: https://auth0.com/docs/api/v2#!/Roles/post_roles
         """
         return self.client.post(self._url(), data=body)
 
@@ -88,7 +92,9 @@ class Roles(object):
         Args:
             id (str): The id of the role to update.
 
-            body (dict): Please see: https://auth0.com/docs/api/management/v2#!/Roles/patch_roles_by_id
+            body (dict): the attributes to update on the role.
+
+        See: https://auth0.com/docs/api/management/v2#!/Roles/patch_roles_by_id
         """
         return self.client.patch(self._url(id), data=body)
 
@@ -98,12 +104,14 @@ class Roles(object):
         Args:
             id (str): The role's id.
 
-            page (int, optional): The result's page number (zero based). 
-  
-            per_page (int, optional): The amount of entries per page. 
+            page (int, optional): The result's page number (zero based). By default,
+               retrieves the first page of results.
+
+            per_page (int, optional): The amount of entries per page. By default,
+               retrieves 25 results per page.
 
             include_totals (bool, optional): True if the query summary is
-                to be included in the result, False otherwise.
+                to be included in the result, False otherwise. Defaults to True.
 
         See https://auth0.com/docs/api/management/v2#!/Roles/get_role_user
         """
@@ -122,7 +130,7 @@ class Roles(object):
         Args:
             id (str): The role's id.
 
-            users (list of str): A list of users ids to add to this role
+            users (list of str): A list of users ids to add to this role.
 
         See https://auth0.com/docs/api/management/v2#!/Roles/post_role_users
         """
@@ -136,12 +144,14 @@ class Roles(object):
         Args:
             id (str): The role's id.
 
-            page (int, optional): The result's page number (zero based). 
-  
-            per_page (int, optional): The amount of entries per page. 
+            page (int, optional): The result's page number (zero based). By default,
+               retrieves the first page of results.
+
+            per_page (int, optional): The amount of entries per page. By default,
+               retrieves 25 results per page.
 
             include_totals (bool, optional): True if the query summary is
-                to be included in the result, False otherwise.
+                to be included in the result, False otherwise. Defaults to True.
 
         See https://auth0.com/docs/api/management/v2#!/Roles/get_role_permission
         """
@@ -167,7 +177,6 @@ class Roles(object):
         body = {'permissions': permissions}
         return self.client.delete(url, data=body)
 
-
     def add_permissions(self, id, permissions):
         """Associates permissions with a role.
 
@@ -180,4 +189,4 @@ class Roles(object):
         """
         url = self._url('{}/permissions'.format(id))
         body = {'permissions': permissions}
-        return self.client.post(url, data=body)
\ No newline at end of file
+        return self.client.post(url, data=body)
